@@ -1,7 +1,13 @@
-## ----load----------------------------------------------------------------
+## ----load, message=FALSE-------------------------------------------------
 library (maptools)
 library (osmplotr)
 
+## ---- echo=FALSE, message=FALSE------------------------------------------
+require (devtools)
+setwd ("../..")
+load_all ("osmplotr")
+setwd ("./osmplotr/vignettes")
+
 ## ---- echo=FALSE, message=FALSE------------------------------------------
 # Combining (dat_B, dat_BC) and (dat_H, dat_HP) requires removing the repeated
 # objects
@@ -12,13 +18,13 @@ dat_H <- spRbind (london$dat_H [indx,], london$dat_HP)
 dat_T <- london$dat_T
 
 ## ------------------------------------------------------------------------
-bbox <- c(-0.15,51.5,-0.1,51.52) 
+bbox <- get_bbox (c(-0.13,51.5,-0.11,51.52))
 
 ## ---- eval=FALSE---------------------------------------------------------
-#  dat_B <- extract_osm_objects (key="building", bbox=bbox)
+#  dat_B <- extract_osm_objects (key="building", bbox=bbox)$obj
 
 ## ----map1, eval=FALSE----------------------------------------------------
-#  plot_osm_basemap (xylims=get_xylims (bbox), bg="gray20", file="map1.png")
+#  plot_osm_basemap (bbox=bbox, bg="gray20", file="map1.png")
 
 ## ---- echo=FALSE---------------------------------------------------------
 graphics.off ()
@@ -27,7 +33,7 @@ graphics.off ()
 #  add_osm_objects (dat_B, col="gray40")
 
 ## ----map2, eval=TRUE, echo=FALSE-----------------------------------------
-plot_osm_basemap (xylims=get_xylims (bbox), bg="gray20", file="map2.png")
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map2.png", width=200)
 add_osm_objects (dat_B, col="gray40")
 graphics.off ()
 
@@ -35,9 +41,9 @@ graphics.off ()
 graphics.off ()
 
 ## ---- eval=FALSE---------------------------------------------------------
-#  dat_B <- extract_osm_objects (key="building", bbox=bbox)
-#  dat_H <- extract_osm_objects (key="highway", bbox=bbox)
-#  dat_T <- extract_osm_objects (key="natural", value="tree", bbox=bbox)
+#  dat_B <- extract_osm_objects (key="building", bbox=bbox)$obj
+#  dat_H <- extract_osm_objects (key="highway", bbox=bbox)$obj
+#  dat_T <- extract_osm_objects (key="natural", value="tree", bbox=bbox)$obj
 
 ## ------------------------------------------------------------------------
 class (dat_B)
@@ -50,23 +56,23 @@ length (dat_H)
 length (dat_T)
 
 ## ------------------------------------------------------------------------
-xylims <- get_xylims (dat_B)
+bbox <- slot (dat_B, "bbox")
 
 ## ----map3, eval=TRUE-----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map3.png")
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map3.png", width=200)
 add_osm_objects (dat_B, col="gray40")
 add_osm_objects (dat_H, col="gray70")
 graphics.off ()
 
 ## ----map4, eval=TRUE-----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map4.png")
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map4.png", width=200)
 add_osm_objects (dat_B, col="gray40", border="orange", lwd=0.2)
 graphics.off ()
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  dat_BR <- extract_osm_objects (key="building", value="residential",
-#                                 bbox=bbox)
-#  dat_HP <- extract_osm_objects (key="highway", value="primary", bbox=bbox)
+#                                 bbox=bbox)$obj
+#  dat_HP <- extract_osm_objects (key="highway", value="primary", bbox=bbox)$obj
 
 ## ---- echo=FALSE---------------------------------------------------------
 dat_BR <- london$dat_BR
@@ -76,32 +82,32 @@ dat_HP <- london$dat_HP
 length (dat_BR)
 
 ## ----map5, eval=TRUE-----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map5.png")
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map5.png", width=200)
 add_osm_objects (dat_BR, col="gray40")
 add_osm_objects (dat_HP, col="gray70")
 graphics.off ()
 
 ## ---- eval=FALSE---------------------------------------------------------
-#  dat_H <- extract_osm_objects (key="highway", value="!primary", bbox=bbox)
+#  dat_H <- extract_osm_objects (key="highway", value="!primary", bbox=bbox)$obj
 
 ## ---- echo=FALSE---------------------------------------------------------
 dat_H <- london$dat_H
 
 ## ----map6, eval=TRUE-----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map6.png")
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map6.png", width=200)
 add_osm_objects (dat_H, col="gray50")
 add_osm_objects (dat_HP, col="gray80")
 graphics.off ()
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  dat_BNR <- extract_osm_objects (key="building", value="!residential",
-#                                  bbox=bbox)
+#                                  bbox=bbox)$obj
 
 ## ---- echo=FALSE---------------------------------------------------------
 dat_BNR <- london$dat_BNR
 
 ## ----map7, eval=TRUE-----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map7.png")
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map7.png", width=200)
 add_osm_objects (dat_BR, col="gray80")
 add_osm_objects (dat_BNR, col="gray40")
 graphics.off ()
@@ -109,21 +115,21 @@ graphics.off ()
 ## ---- eval=FALSE---------------------------------------------------------
 #  extra_pairs <- c ("name", "Royal.Festival.Hall")
 #  dat_RFH <- extract_osm_objects (key="building", extra_pairs=extra_pairs,
-#                                  bbox=bbox)
+#                                  bbox=bbox)$obj
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  extra_pairs <- list (c ("addr:street", "Stamford.St"),
 #                       c ("addr:housenumber", "150"))
 #  dat_ST <- extract_osm_objects (key="building", extra_pairs=extra_pairs,
-#                                  bbox=bbox)
+#                                  bbox=bbox)$obj
 
 ## ---- echo=FALSE---------------------------------------------------------
 dat_RFH <- london$dat_RFH
 dat_ST <- london$dat_ST
 
 ## ----map8, eval=TRUE-----------------------------------------------------
-xylims <- list (xrange=c(-0.118, -0.110), yrange=c(51.504, 51.507))
-plot_osm_basemap (xylims=xylims, bg="gray95", file="map8.png", width=480)
+bbox <- get_bbox (c (-0.118, 51.504, -0.110, 51.507))
+plot_osm_basemap (bbox=bbox, bg="gray95", file="map8.png", width=200)
 add_osm_objects (dat_H, col="gray80")
 add_osm_objects (dat_HP, col="gray60", lwd=4)
 add_osm_objects (dat_RFH, col="orange", border="red", lwd=3)
@@ -161,20 +167,22 @@ structures
 ## ---- eval=FALSE---------------------------------------------------------
 #  extra_pairs <- c ("name", "Royal.Festival.Hall")
 #  london$dat_RFH <- extract_osm_objects (key="building", extra_pairs=extra_pairs,
-#                                  bbox=bbox)
+#                                  bbox=bbox)$obj
 #  extra_pairs <- list (c ("addr:street", "Stamford.St"),
 #                       c ("addr:housenumber", "150"))
 #  london$dat_ST <- extract_osm_objects (key="building", extra_pairs=extra_pairs,
-#                                  bbox=bbox)
+#                                  bbox=bbox)$obj
 
 ## ----map9, eval=TRUE-----------------------------------------------------
 osm_data <- make_osm_map (osm_data=london, structures=structures, 
-                          dat_prefix="dat_", file="map9.png")
+                          dat_prefix="dat_", file="map9.png", width=200)
 graphics.off ()
 
 ## ----map10, eval=TRUE----------------------------------------------------
+bbox <- get_bbox (c(-0.13,51.5,-0.11,51.52))
 osm_data <- make_osm_map (osm_data=london, structures=structures, 
-                          dat_prefix="dat_", bbox=bbox, file="map10.png")
+                          dat_prefix="dat_", bbox=bbox, file="map10.png",
+                          width=200)
 graphics.off ()
 
 ## ---- echo=FALSE---------------------------------------------------------
@@ -182,68 +190,62 @@ indx <- which (!london$dat_BR$id %in% london$dat_BNR$id)
 dat_B <- spRbind (london$dat_BR [indx,], london$dat_BNR)
 
 ## ----map11, eval=TRUE----------------------------------------------------
-pts <- sp::SpatialPoints (cbind (c (-0.120, -0.135, -0.135, -0.120),
+pts <- sp::SpatialPoints (cbind (c (-0.115, -0.125, -0.125, -0.115),
                              c (51.510, 51.510, 51.516, 51.516)))
-xylims <- get_xylims (c (-0.14, 51.505, -0.11, 51.52))
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map11.png")
-group_osm_objects (dat_B, groups=pts, col="orange", col_extra="gray40",
+bbox <- get_bbox (c(-0.13,51.5,-0.11,51.52))
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map11.png", width=200)
+add_osm_groups (dat_B, groups=pts, col="orange", col_extra="gray40",
                    colmat=FALSE) 
 graphics.off ()
 
 ## ----map12, eval=TRUE----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map12.png")
-group_osm_objects (dat_B, pts, col="orange", col_extra="gray40", colmat=FALSE,
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map12.png", width=200)
+add_osm_groups (dat_B, pts, col="orange", col_extra="gray40", colmat=FALSE,
                    boundary=0)
 graphics.off ()
 
 ## ----map13, eval=TRUE----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map13.png")
-group_osm_objects (dat_B, groups=pts, col="orange", col_extra="gray40", 
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map13.png", width=200)
+add_osm_groups (dat_B, groups=pts, col="orange", col_extra="gray40", 
                    colmat=FALSE, boundary=1)
 graphics.off ()
 
 ## ------------------------------------------------------------------------
-xylims <- get_xylims (c (-0.15, 51.5, -0.1, 51.52)) # zoom out again
-pts <- sp::SpatialPoints (cbind (c (-0.128, -0.138, -0.138, -0.128),
-                             c (51.502, 51.502, 51.515, 51.515)))
+pts <- sp::SpatialPoints (cbind (c (-0.117, -0.122, -0.122, -0.117),
+                                 c (51.512, 51.512, 51.518, 51.518)))
 
 ## ----map14, eval=TRUE----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map14.png")
-group_osm_objects (dat_B, groups=pts, col="orange", col_extra="gray40", 
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map14.png", width=200)
+add_osm_groups (dat_B, groups=pts, col="orange", col_extra="gray40", 
                    colmat=FALSE, boundary=1)
 col_park_in <- rgb (50, 255, 50, maxColorValue=255)
 col_park_out <- rgb (50, 155, 50, maxColorValue=255)
-group_osm_objects (london$dat_P, groups=pts, col=col_park_in, 
+add_osm_groups (london$dat_P, groups=pts, col=col_park_in, 
                    col_extra=col_park_out, colmat=FALSE, boundary=0)
 graphics.off ()
 
-## ------------------------------------------------------------------------
-xylims <- get_xylims (c (-0.15, 51.5, -0.1, 51.52)) # zoom out again
-pts <- sp::SpatialPoints (cbind (c (-0.128, -0.138, -0.138, -0.128),
-                             c (51.502, 51.502, 51.515, 51.515)))
-
 ## ----map15, eval=TRUE----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map15.png")
-group_osm_objects (dat_B, groups=pts, col="orange", col_extra="gray40", 
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map15.png", width=200)
+add_osm_groups (dat_B, groups=pts, col="orange", col_extra="gray40", 
                    colmat=FALSE, boundary=1)
 add_osm_objects (london$dat_P, col=col_park_out)
 col_park_in <- rgb (50, 255, 50, maxColorValue=255)
 col_park_out <- rgb (50, 155, 50, maxColorValue=255)
-group_osm_objects (london$dat_P, groups=pts, col=col_park_in, 
+add_osm_groups (london$dat_P, groups=pts, col=col_park_in, 
                    col_extra=col_park_out, colmat=FALSE, boundary=0)
 graphics.off ()
 
 ## ----map16, eval=TRUE----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray95", file="map16.png")
-group_osm_objects (dat_B, groups=pts, col="gray40", col_extra="gray85",
+plot_osm_basemap (bbox=bbox, bg="gray95", file="map16.png", width=200)
+add_osm_groups (dat_B, groups=pts, col="gray40", col_extra="gray85",
                    colmat=FALSE, boundary=1)
-group_osm_objects (dat_H, groups=pts, col="gray20", col_extra="gray70",
+add_osm_groups (dat_H, groups=pts, col="gray20", col_extra="gray70",
                    colmat=FALSE, boundary=0)
-group_osm_objects (dat_HP, groups=pts, col="gray10", col_extra="white",
+add_osm_groups (dat_HP, groups=pts, col="gray10", col_extra="white",
                    colmat=FALSE, boundary=0)
 graphics.off ()
 
-## ---- fig.width=5--------------------------------------------------------
+## ---- fig.width=4--------------------------------------------------------
 plot.new ()
 cmat <- colour_mat (plot=TRUE)
 graphics.off ()
@@ -253,8 +255,8 @@ set.seed (2)
 
 ## ------------------------------------------------------------------------
 ngroups <- 12
-x <- xylims$xrange [1] + runif (ngroups) * diff (xylims$xrange)
-y <- xylims$yrange [1] + runif (ngroups) * diff (xylims$yrange)
+x <- bbox [1,1] + runif (ngroups) * diff (bbox [1,])
+y <- bbox [2,1] + runif (ngroups) * diff (bbox [2,])
 groups <- cbind (x, y)
 groups <- apply (groups, 1, function (i) 
               sp::SpatialPoints (matrix (i, nrow=1, ncol=2)))
@@ -269,14 +271,14 @@ groups <- lapply (groups, function (i)
                })
 
 ## ----map17, eval=TRUE----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map17.png")
-group_osm_objects (dat_B, groups=groups, col_extra=NA, make_hull=FALSE,
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map17.png", width=200)
+add_osm_groups (dat_B, groups=groups, col_extra=NA, make_hull=FALSE,
                    colmat=TRUE, lwd=3)
 graphics.off ()
 
 ## ----map18, eval=TRUE----------------------------------------------------
-plot_osm_basemap (xylims=xylims, bg="gray20", file="map18.png")
-group_osm_objects (dat_B, groups=groups, col_extra=NA, make_hull=FALSE,
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map18.png", width=200)
+add_osm_groups (dat_B, groups=groups, col_extra=NA, make_hull=FALSE,
                    colmat=TRUE, rotate=90, lwd=3)
 graphics.off ()
 
@@ -305,22 +307,26 @@ for (i in seq (ncol (cols)))
 col_extra_H <- "gray20"
 
 ## ---- echo=FALSE, eval=TRUE----------------------------------------------
-plot_osm_basemap (xylims=get_xylims (bbox), bg="gray20", file="map19.png")
+plot_osm_basemap (bbox=bbox, bg="gray20")
+plot_osm_basemap (bbox=bbox, bg="gray20", file="map19.png", width=200)
 add_osm_objects (london$dat_P, col=col_G)
 add_osm_objects (london$dat_G, col=col_G)
 add_osm_objects (london$dat_N, col=col_G)
 add_osm_objects (london$dat_A, col=col_A)
-group_osm_objects (london$dat_BNR, groups=groups, boundary=0,
+add_osm_groups (london$dat_BNR, groups=groups, boundary=0,
                    col_extra=col_extra_B, colmat=FALSE, col=cols_B)
-group_osm_objects (london$dat_BR, groups=groups, boundary=0,
+add_osm_groups (london$dat_BR, groups=groups, boundary=0,
                    col_extra=col_extra_B, colmat=FALSE, col=cols_B)
 
-group_osm_objects (london$dat_H, groups=groups, boundary=0,
+add_osm_groups (london$dat_H, groups=groups, boundary=0,
                    col_extra=col_extra_H, colmat=FALSE, col=cols_H)
-group_osm_objects (london$dat_HP, groups=groups, boundary=0,
+add_osm_groups (london$dat_HP, groups=groups, boundary=0,
                    col_extra=col_extra_H, colmat=FALSE, col=cols_H)
 graphics.off ()
 
+## ------------------------------------------------------------------------
+bbox <- get_bbox (c(-0.15,51.5,-0.1,51.52)) 
+
 ## ---- eval=FALSE---------------------------------------------------------
 #  highways <- c ("Kingsway", "Holborn", "Farringdon.St", "Strand",
 #                 "Fleet.St", "Aldwych")
@@ -353,8 +359,9 @@ groups <- list (london$highways1, london$highways2, london$highways3)
 ## ---- eval=TRUE----------------------------------------------------------
 structures <- c ("amenity", "grass", "park", "natural")
 structs <- osm_structures (structures=structures, col_scheme="dark")
+bbox <- get_bbox (c(-0.13,51.5,-0.11,51.52)) # back to smaller bbox
 junk <- make_osm_map (filename="map20.png", bbox=bbox, 
-                      osm_data=london, structures=structs)
+                      osm_data=london, structures=structs, width=200)
 graphics.off ()
 
 ## ---- message=FALSE------------------------------------------------------
@@ -380,19 +387,20 @@ col_extra_B <- st_all$cols [which (st_all$structure == "building")]
 col_extra_H <- "gray20"
 
 ## ---- eval=FALSE---------------------------------------------------------
-#  group_osm_objects (london$dat_BNR, groups=groups, boundary=0,
+#  add_osm_groups (london$dat_BNR, groups=groups, boundary=0,
 #                     col_extra=col_extra_B, colmat=FALSE, col=cols)
-#  group_osm_objects (london$dat_BR, groups=groups, boundary=0,
+#  add_osm_groups (london$dat_BR, groups=groups, boundary=0,
 #                     col_extra=col_extra_B, colmat=FALSE, col=cols)
 #  
-#  group_osm_objects (london$dat_H, groups=groups, boundary=0,
+#  add_osm_groups (london$dat_H, groups=groups, boundary=0,
 #                     col_extra=col_extra_H, colmat=FALSE, col=cols_dark)
-#  group_osm_objects (london$dat_HP, groups=groups, boundary=0,
+#  add_osm_groups (london$dat_HP, groups=groups, boundary=0,
 #                     col_extra=col_extra_H, colmat=FALSE, col=cols_dark)
 #  graphics.off ()
 
-## ---- fig.width=7, message=FALSE, eval=TRUE------------------------------
+## ----highways2polygon, fig.width=4, message=FALSE, eval=TRUE-------------
 highways <- c ("Kingsway", "Holborn", "Farringdon.St", "Strand",
                "Fleet.St", "Aldwych")
+bbox <- get_bbox (c(-0.15,51.5,-0.1,51.52)) # need larger bbox
 highway_list <- highways2polygon (highways=highways, bbox=bbox, plot=TRUE)
 
